import { BaseBackend } from '@sentry/core';
import { SentryError } from '@sentry/utils';
/** IPC to ping the main process when initializing in the renderer. */
export const IPC_PING = 'sentry-electron.ping';
/** IPC to send a captured event (exception or message) to Sentry. */
export const IPC_EVENT = 'sentry-electron.event';
/** IPC to capture a scope globally. */
export const IPC_SCOPE = 'sentry-electron.scope';
export const SDK_NAME = 'sentry.javascript.electron';
/** Get the name of an electron app for <v5 and v7< */
export function getNameFallback() {
    // tslint:disable-next-line: strict-type-predicates
    if (!require) {
        throw new SentryError('Could not require("electron") to get appName. Please ensure you pass `appName` to Sentry options');
    }
    const electron = require('electron');
    // if we're in the main process
    if (electron && electron.app) {
        const appMain = electron.app;
        return appMain.name || appMain.getName();
    }
    // We're in the renderer process but the remote module is not available
    if (!electron || !electron.remote) {
        throw new SentryError('The Electron `remote` module was not available to get appName. Please ensure you pass `appName` to Sentry options');
    }
    // Remote is available so get the app name
    const a = electron.remote.app;
    return a.name || a.getName();
}
/** Common interface for Electron backends. */
export { BaseBackend as CommonBackend };
//# sourceMappingURL=common.js.map