import { __awaiter } from "tslib";
import { getCurrentHub } from '@sentry/core';
import { Severity } from '@sentry/types';
import { isError } from '@sentry/utils';
import { dialog } from 'electron';
/** Capture unhandled erros. */
export class OnUncaughtException {
    /**
     * @inheritDoc
     */
    constructor(_options = {}) {
        this._options = _options;
        /**
         * @inheritDoc
         */
        this.name = OnUncaughtException.id;
    }
    /**
     * @inheritDoc
     */
    setupOnce() {
        global.process.on('uncaughtException', (error) => {
            const self = getCurrentHub().getIntegration(OnUncaughtException);
            if (self) {
                getCurrentHub().withScope((scope) => __awaiter(this, void 0, void 0, function* () {
                    scope.addEventProcessor((event) => __awaiter(this, void 0, void 0, function* () {
                        return (Object.assign(Object.assign({}, event), { level: Severity.Fatal }));
                    }));
                    let theError = error;
                    if (!isError(error) && error.stack) {
                        theError = new Error();
                        theError.message = error.message;
                        theError.stack = error.stack;
                        theError.name = error.name;
                    }
                    const nodeClient = getCurrentHub().getClient();
                    nodeClient.captureException(theError, { originalException: error }, getCurrentHub().getScope());
                    yield nodeClient.flush(nodeClient.getOptions().shutdownTimeout || 2000);
                    if (this._options.onFatalError) {
                        this._options.onFatalError(error);
                    }
                    else if (global.process.listenerCount('uncaughtException') <= 2) {
                        // In addition to this handler there is always one in Electron
                        // The dialog is only shown if there are no other handlers
                        console.error('Uncaught Exception:');
                        console.error(error);
                        const ref = error.stack;
                        const stack = ref !== undefined ? ref : `${error.name}: ${error.message}`;
                        const message = `Uncaught Exception:\n${stack}`;
                        dialog.showErrorBox('A JavaScript error occurred in the main process', message);
                    }
                }));
            }
        });
    }
}
/**
 * @inheritDoc
 */
OnUncaughtException.id = 'OnUncaughtException';
//# sourceMappingURL=onuncaughtexception.js.map